@@ -461,7 +461,6 @@ void Application::readOptions()
     if(!groups.isEmpty())
     {
         Konversation::ServerGroupHash serverGroups;
-        int index = 0;
         Konversation::ChannelList channelHistory;
         Konversation::ServerSettings server;
         Konversation::ChannelSettings channel;
@@ -470,7 +469,7 @@ void Application::readOptions()
             KConfigGroup cgServerGroup(KSharedConfig::openConfig()->group(groupName));
             Konversation::ServerGroupSettingsPtr serverGroup(new Konversation::ServerGroupSettings);
             serverGroup->setName(cgServerGroup.readEntry("Name"));
-            serverGroup->setSortIndex(groups.at(index).section(QLatin1Char(' '), -1).toInt());
+            serverGroup->setSortIndex(groupName.section(QLatin1Char(' '), -1).toInt());
             serverGroup->setIdentityId(Preferences::identityByName(cgServerGroup.readEntry("Identity"))->id());
             serverGroup->setConnectCommands(cgServerGroup.readEntry("ConnectCommands"));
             serverGroup->setAutoConnectEnabled(cgServerGroup.readEntry("AutoConnect", false));
@@ -528,8 +527,6 @@ void Application::readOptions()
 
             serverGroups.insert(serverGroup->id(), serverGroup);
             sgKeys.append(serverGroup->id());
-
-            index++;
         }
 
         Preferences::setServerGroupHash(serverGroups);
@@ -817,22 +814,17 @@ void Application::saveOptions(bool updateGUI)
     index = 0;
     int index2 = 0;
     int index3 = 0;
-    int width = 0;
-    QList<int> keys = serverGroupHash.keys();
-    for(int i=0; i<keys.count(); i++)
-        if(width < keys.at(i)) width = keys.at(i);
-    width = QString(width).length(); // TODO: broken, always yield 1
     QStringList servers;
     QStringList channels;
     QStringList channelHistory;
-    QList<int> sgKeys;
+    QHash<int, int> sgKeys;
 
     for (const auto& serverGroup : qAsConst(sortedServerGroupMap)) {
         const Konversation::ServerList serverList = serverGroup->serverList();
         servers.clear();
         servers.reserve(serverList.size());
 
-        sgKeys.append(serverGroup->id());
+        sgKeys.insert(serverGroup->id(), index);
 
         for (const auto& server : serverList) {
             const QString groupName = QStringLiteral("Server %1").arg(index2);
@@ -874,7 +866,7 @@ void Application::saveOptions(bool updateGUI)
             index3++;
         }
 
-        QString sgn = QStringLiteral("ServerGroup %1").arg(QString::number(index).rightJustified(width,QLatin1Char('0')));
+        QString sgn = QStringLiteral("ServerGroup %1").arg(index);
         KConfigGroup cgServerGroup(KSharedConfig::openConfig()->group(sgn));
         cgServerGroup.writeEntry("Name", serverGroup->name());
         cgServerGroup.writeEntry("Identity", serverGroup->identity()->getName());
@@ -917,7 +909,7 @@ void Application::saveOptions(bool updateGUI)
                 QString enc = Preferences::channelEncoding(encServer, encChannel);
                 QString key = QLatin1Char(' ') + encChannel;
                 if (sgKeys.contains(encServer))
-                    key.prepend(QStringLiteral("ServerGroup ") + QString::number(sgKeys.indexOf(encServer)));
+                    key.prepend(QStringLiteral("ServerGroup ") + QString::number(sgKeys.value(encServer)));
                 else
                     key.prepend(sgsp->name());
                 cgEncoding.writeEntry(key, enc);
@@ -941,10 +933,8 @@ void Application::saveOptions(bool updateGUI)
         {
             i2.next();
 
-            int serverGroupIndex = sgKeys.indexOf(i.key()->id());
-
-            if (serverGroupIndex != -1)
-                cgSpellCheckingLanguages.writeEntry(QStringLiteral("ServerGroup ") + QString::number(serverGroupIndex) + QLatin1Char(' ') + i2.key(), i2.value());
+            if (sgKeys.contains(i.key()->id()))
+                cgSpellCheckingLanguages.writeEntry(QStringLiteral("ServerGroup ") + QString::number(sgKeys.value(i.key()->id())) + QLatin1Char(' ') + i2.key(), i2.value());
         }
     }
 
