@@ -1,20 +1,8 @@
-// Copyright 2009  Peter Simonsson <peter.simonsson@gmail.com>
-//
-// This program is free software; you can redistribute it and/or
-// modify it under the terms of the GNU General Public License as
-// published by the Free Software Foundation; either version 2 of
-// the License or (at your option) version 3 or any later version
-// accepted by the membership of KDE e.V. (or its successor approved
-// by the membership of KDE e.V.), which shall act as a proxy
-// defined in Section 14 of version 3 of the license.
-//
-// This program is distributed in the hope that it will be useful,
-// but WITHOUT ANY WARRANTY; without even the implied warranty of
-// MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
-// GNU General Public License for more details.
-//
-// You should have received a copy of the GNU General Public License
-// along with this program.  If not, see <http://www.gnu.org/licenses/>.
+/*
+    SPDX-License-Identifier: GPL-2.0-only OR GPL-3.0-only OR LicenseRef-KDE-Accepted-GPL
+
+    SPDX-FileCopyrightText: 2009 Peter Simonsson <peter.simonsson@gmail.com>
+*/
 
 #include "invitedialog.h"
 
@@ -24,7 +12,6 @@
 
 #include <QStringList>
 #include <KSharedConfig>
-#include <QDialogButtonBox>
 #include <QPushButton>
 #include <QVBoxLayout>
 
@@ -82,12 +69,12 @@ bool InviteDialog::shouldBeShown(QDialogButtonBox::StandardButton& buttonCode)
     cg.sync();
     const QString dontAsk = cg.readEntry("Invitation", QString()).toLower();
 
-    if (dontAsk == QStringLiteral("1"))
+    if (dontAsk == QLatin1Char('1'))
     {
     buttonCode = QDialogButtonBox::Ok;
     return false;
     }
-    else if (dontAsk == QStringLiteral("2"))
+    else if (dontAsk == QLatin1Char('2'))
     {
     buttonCode = QDialogButtonBox::Cancel;
     return false;
@@ -112,7 +99,7 @@ void InviteChannelListModel::addInvite(const QString& nickname, const QString& c
     {
         if(!m_channelMap[channel].nicknames.contains(nickname))
         {
-            m_channelMap[channel].nicknames += QStringLiteral(", ") + nickname;
+            m_channelMap[channel].nicknames += QLatin1String(", ") + nickname;
         }
     }
     else
@@ -157,7 +144,7 @@ QVariant InviteChannelListModel::data(const QModelIndex& index, int role) const
     }
     if(role == Qt::SizeHintRole)
     {
-        return QSize(0, qMax(qApp->style()->sizeFromContents(QStyle::CT_CheckBox, 0, QSize(0, 0), 0).height(),
+        return QSize(0, qMax(qApp->style()->sizeFromContents(QStyle::CT_CheckBox, nullptr, QSize(0, 0), nullptr).height(),
                              qApp->fontMetrics().height()));
     }
     else if((role == Qt::CheckStateRole) && (index.column() == 0))
@@ -198,13 +185,12 @@ QString InviteChannelListModel::selectedChannels() const
 {
     QStringList channels;
 
-    foreach(const ChannelItem& item, m_channelMap)
-    {
+    for (const ChannelItem& item : m_channelMap) {
         if(item.checkState == Qt::Checked)
             channels.append(item.channel);
     }
 
-    return channels.join(QStringLiteral(","));
+    return channels.join(QLatin1Char(','));
 }
 
 bool InviteChannelListModel::setData(const QModelIndex& index, const QVariant& value, int role)
